from aiobaseclient import BaseStandardClient
from izihawa_loglib.request_context import RequestContext
from izihawa_utils.common import filter_none
from spacefrontiers.clients.types import ConversationRequest, ConversationResponse


class SearchApiClient(BaseStandardClient):
    """Client for interacting with the Search API.

    A client that handles communication with the Search API endpoints, including authentication
    and request handling.

    Args:
        base_url (str): The base URL of the Search API.
        api_key (str | None, optional): API key for authentication. Defaults to None.
        user_id (str | int | None, optional): User ID of the user. Defaults to None.
        max_retries (int, optional): Maximum number of retry attempts. Defaults to 2.
        retry_delay (float, optional): Delay between retry attempts in seconds. Defaults to 0.5.
    """

    def __init__(
        self,
        base_url: str,
        api_key: str | None = None,
        user_id: str | int | None = None,
        max_retries: int = 2,
        retry_delay: float = 0.5,
        default_headers: dict[str, str] | None = None,
    ):
        if default_headers is None:
            default_headers = {}
        if api_key is not None:
            default_headers["X-Sf-Api-Key"] = api_key
        if user_id is not None:
            default_headers["X-Sf-User-Id"] = str(user_id)
        super().__init__(
            base_url=base_url,
            default_headers=default_headers,
            max_retries=max_retries,
            retry_delay=retry_delay,
        )

    async def post_conversations(
        self,
        conversation_request: ConversationRequest,
        timeout: float = 60.0,
        request_context: RequestContext | None = None,
    ) -> ConversationResponse:
        """Execute a conversation search request.

        Args:
            conversation_request (ConversationRequest): The conversation request parameters.
            timeout (float, optional): Request timeout in seconds. Defaults to 60.0.
            request_context (RequestContext | None, optional): Context for the request. Defaults to None.

        Returns:
            ConversationResponse: The conversation response
        """
        response = await self.post(
            "/v1/conversations/",
            json=filter_none(conversation_request.model_dump(exclude_none=True)),
            request_context=request_context,
            timeout=timeout,
        )
        return ConversationResponse(**response)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class EmbedRequest(_message.Message):
    __slots__ = ("texts", "task")
    TEXTS_FIELD_NUMBER: _ClassVar[int]
    TASK_FIELD_NUMBER: _ClassVar[int]
    texts: _containers.RepeatedScalarFieldContainer[str]
    task: str
    def __init__(
        self, texts: _Optional[_Iterable[str]] = ..., task: _Optional[str] = ...
    ) -> None: ...

class Embedding(_message.Message):
    __slots__ = ("vector",)
    VECTOR_FIELD_NUMBER: _ClassVar[int]
    vector: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, vector: _Optional[_Iterable[float]] = ...) -> None: ...

class EmbedResponse(_message.Message):
    __slots__ = ("embeddings", "processed_tokens")
    EMBEDDINGS_FIELD_NUMBER: _ClassVar[int]
    PROCESSED_TOKENS_FIELD_NUMBER: _ClassVar[int]
    embeddings: _containers.RepeatedCompositeFieldContainer[Embedding]
    processed_tokens: int
    def __init__(
        self,
        embeddings: _Optional[_Iterable[_Union[Embedding, _Mapping]]] = ...,
        processed_tokens: _Optional[int] = ...,
    ) -> None: ...

class RerankRequest(_message.Message):
    __slots__ = ("query", "texts")
    QUERY_FIELD_NUMBER: _ClassVar[int]
    TEXTS_FIELD_NUMBER: _ClassVar[int]
    query: str
    texts: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self, query: _Optional[str] = ..., texts: _Optional[_Iterable[str]] = ...
    ) -> None: ...

class RerankItem(_message.Message):
    __slots__ = ("score", "index")
    SCORE_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    score: float
    index: int
    def __init__(
        self, score: _Optional[float] = ..., index: _Optional[int] = ...
    ) -> None: ...

class RerankResponse(_message.Message):
    __slots__ = ("scores", "processed_tokens")
    SCORES_FIELD_NUMBER: _ClassVar[int]
    PROCESSED_TOKENS_FIELD_NUMBER: _ClassVar[int]
    scores: _containers.RepeatedCompositeFieldContainer[RerankItem]
    processed_tokens: int
    def __init__(
        self,
        scores: _Optional[_Iterable[_Union[RerankItem, _Mapping]]] = ...,
        processed_tokens: _Optional[int] = ...,
    ) -> None: ...

class OcrRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class OcrResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 29, 0, "", "service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rservice.proto\x12\x05\x61i.v1"+\n\x0c\x45mbedRequest\x12\r\n\x05texts\x18\x01 \x03(\t\x12\x0c\n\x04task\x18\x02 \x01(\t"\x1b\n\tEmbedding\x12\x0e\n\x06vector\x18\x01 \x03(\x02"O\n\rEmbedResponse\x12$\n\nembeddings\x18\x01 \x03(\x0b\x32\x10.ai.v1.Embedding\x12\x18\n\x10processed_tokens\x18\x02 \x01(\r"-\n\rRerankRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\r\n\x05texts\x18\x02 \x03(\t"*\n\nRerankItem\x12\r\n\x05score\x18\x01 \x01(\x02\x12\r\n\x05index\x18\x02 \x01(\r"M\n\x0eRerankResponse\x12!\n\x06scores\x18\x01 \x03(\x0b\x32\x11.ai.v1.RerankItem\x12\x18\n\x10processed_tokens\x18\x02 \x01(\r"\x0c\n\nOcrRequest"\r\n\x0bOcrResponse2=\n\x05\x45mbed\x12\x34\n\x05\x65mbed\x12\x13.ai.v1.EmbedRequest\x1a\x14.ai.v1.EmbedResponse"\x00\x32\x41\n\x06Rerank\x12\x37\n\x06rerank\x12\x14.ai.v1.RerankRequest\x1a\x15.ai.v1.RerankResponse"\x00\x32\x35\n\x03Ocr\x12.\n\x03ocr\x12\x11.ai.v1.OcrRequest\x1a\x12.ai.v1.OcrResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "service_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_EMBEDREQUEST"]._serialized_start = 24
    _globals["_EMBEDREQUEST"]._serialized_end = 67
    _globals["_EMBEDDING"]._serialized_start = 69
    _globals["_EMBEDDING"]._serialized_end = 96
    _globals["_EMBEDRESPONSE"]._serialized_start = 98
    _globals["_EMBEDRESPONSE"]._serialized_end = 177
    _globals["_RERANKREQUEST"]._serialized_start = 179
    _globals["_RERANKREQUEST"]._serialized_end = 224
    _globals["_RERANKITEM"]._serialized_start = 226
    _globals["_RERANKITEM"]._serialized_end = 268
    _globals["_RERANKRESPONSE"]._serialized_start = 270
    _globals["_RERANKRESPONSE"]._serialized_end = 347
    _globals["_OCRREQUEST"]._serialized_start = 349
    _globals["_OCRREQUEST"]._serialized_end = 361
    _globals["_OCRRESPONSE"]._serialized_start = 363
    _globals["_OCRRESPONSE"]._serialized_end = 376
    _globals["_EMBED"]._serialized_start = 378
    _globals["_EMBED"]._serialized_end = 439
    _globals["_RERANK"]._serialized_start = 441
    _globals["_RERANK"]._serialized_end = 506
    _globals["_OCR"]._serialized_start = 508
    _globals["_OCR"]._serialized_end = 561
# @@protoc_insertion_point(module_scope)
